"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.encodePubSubMessage = exports.decodePubSubMessage = void 0;
/**
 * Decode a PubSub message.
 * @param message The PubSub message.
 * @param parser The message parser (defaults to {@see JSON.parse}); other string to data might be supplied.
 */
function decodePubSubMessage(message, parser) {
    var _a;
    if (parser === void 0) { parser = JSON.parse; }
    if (!message.data) {
        throw new Error('Invalid PubSub message: missing data key.');
    }
    try {
        return parser(Buffer.from(message.data, 'base64').toString('utf-8'));
    }
    catch (e) {
        throw new Error("Unable to parse the message.data: " + ((_a = e === null || e === void 0 ? void 0 : e.message) !== null && _a !== void 0 ? _a : e.toString()));
    }
}
exports.decodePubSubMessage = decodePubSubMessage;
/**
 * Encode a PubSub message.
 * @param data The data to encode.
 */
function encodePubSubMessage(data) {
    return Buffer.from(JSON.stringify({ data: { message: data } }), 'utf-8');
}
exports.encodePubSubMessage = encodePubSubMessage;
//# sourceMappingURL=pub-sub.js.map